# Generated by Django 2.1.4 on 2019-01-18 13:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('document', '0005_document_template'),
    ]

    operations = [
        migrations.AlterField(
            model_name='document',
            name='doc_version',
            field=models.DecimalField(decimal_places=1, default=3.0, max_digits=3),
        ),
    ]
