body.editor {
    width: 100%;
    height: 100%;
    font-family: 'Lato', sans-serif;
    font-size: 13px;
    color: #2c2723;
    width: 100%;
    background-color: #f2f2f2;
}

header {
    position: fixed;
    width: 100%;
    z-index: 100;
}

#document-top {
    padding: 16px 0;
    background-color: #84b4a7;
    width: 100%;
    border-bottom: 1px solid #c2dad3;
}

#document-top>h1 {
    font-size: 22px;
    color: #fff;
    font-style: italic;
    padding: 0 48px 0 110px;
    background: url(../img/fidus_face.png) no-repeat 42px 0;
    background-size: 23px auto;
    line-height: 32px;
    overflow: hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
}

#header-navigation {
    position: relative;
    margin: 20px 0 0 110px;
    -webkit-user-select: none;
}

#header-navigation>div {
    position: relative;
    display: inline-block;
    margin-right: 18px;
    height: 18px;
    overflow: visible;
}

#header-navigation span {
    cursor: pointer;
}

#header-navigation .header-nav-item {
    opacity: 0.6;
    line-height: 35px;
}

#header-navigation .header-nav-item:hover {
    opacity: 1;
}

#header-navigation span.deactivated {
    text-decoration: line-through;
}

#header-navigation span.disabled,
#toolbar span.disabled {
    color: #ccc !important;
    text-shadow: none;
}

#header-navigation span.selected.disabled,
#toolbar span.selected.disabled {
    background-color: #ccc;
    color: white !important;
}

/*
 * Selection Menu style
 */
#selection-menu {
    margin-left: -23px;
    z-index: 1;
}

#selection-menu > div {
    width: 46px;
}


/*
 * Toolbar Style
 */

#toolbar {
    display: block;
    z-index: 88;
    width: 100%;
    -webkit-user-select: none;
    padding: 34px 0;
    background-color: #f2f2f2;
}

#ice-control {
    right: 0;
}

#comments-display {
    left: 100%;
    margin-left: 14px;
    background-color: #fbf9d2;
    vertical-align: top;
}

#comments-display.selected {
    background-color: #f9f9f9;
}

#comments-display:hover {
    background-color: #e0e0e0;
}

#comments-display.disabled {
    color: #ccc;
    background-color: #f9f9f9;
}

#reviewed {
    left: 100%;
    margin-left: 14px;
    background-color: #81F781;
}

#reviewed:hover {
    background-color: #e0e0e0;
}

.editor-toolbar {
    position: relative;
    width: auto !important;
    padding-left: 110px
}

.editor-toolbar div.ui-buttonset {
    position: relative;
    display: inline-block;
    white-space: nowrap;
    vertical-align: top;
    margin-right: 6px;
}

.editor-toolbar div.ui-buttonset:first-child {
    position: absolute;
    left: 30px;
}

.editor-toolbar div.info {
    /*max-width: 90px;*/
    min-width: 62px;
    color: #000;
    background-color: #f9f9f9;
    text-shadow: none;
    border-color: #e0e0e0;
    height: 46px;
    line-height: 46px;
    padding: 0 10px;
    display: inline-block;
    font-size: 14px;
    border-width: 0px;
    border-radius: 23px;
    text-decoration: none;
    box-shadow: none;
    box-sizing: content-box;
    white-space: nowrap;
    margin-right: 6px;
    text-align: center;
}

.editor-toolbar div.multiButtons {
    width: auto;
}

.editor-toolbar div.multiButtons .multibuttonsCover {
    position: relative;
    min-width: 85px;
    max-width: 120px;
    font-size: 11px;
    font-weight: 700;
    color: #2c2723;
    font-family: Lato;
    font-size: 13px;
    font-weight: 700;
    letter-spacing: 0.07px;
    padding: 0 40px 0 20px;
}

.editor-toolbar div.multiButtons .multibuttonsCover:after {
    display: block;
    position: absolute;
    right: 10px;
    top: 16px;
    text-align: right;
    margin-top: 0;
    width: 9px;
    height: 5px;
    opacity: 0.5;
    color: #262626;
    font-size: 15px;
    line-height: 15.75px;
    letter-spacing: 0.15px;
}

.editor-toolbar div.multiButtons .multibuttonsCover.disabled:after {
    display: none;
}

.editor-toolbar .fw-button.no-border {
    background: transparent;
    border-color: transparent;
}

.editor-toolbar .fw-button.no-border .ui-button-text {
    width: 10px;
    height: 10px;
    opacity: 0.4;
    color: #262626;
    font-size: 17px;
    font-weight: 400;
    line-height: 15.75px;
    letter-spacing: 0.17px;
}

.editor-toolbar .fw-button, .editor-selection-menu .fw-button {
    border-width: 0px;
}

.editor-selection-menu .fw-button {
    margin-bottom: 4px;
}


.editor-toolbar .fw-button.fw-large, .editor-selection-menu .fw-button.fw-large {
    height: 46px;
    line-height: 46px;
    border-radius: 23px;
}

.editor-toolbar .fw-button.fw-large.fw-square, .editor-selection-menu .fw-button.fw-large.fw-square {
    width: 46px;
}

.ui-dialog-content-table .dk_toggle {
    width: 533px !important;
}

.ui-dialog-content-table .dk_options_inner a {
    white-space: nowrap;
    overflow: hidden;
}

.ui-dialog-content.math {
    min-width: 200px;
    padding-right: 50px;
    padding-bottom: 10px;
}

.ML__fieldcontainer__field {
    min-height: 23px;
}

div#statusarea {
    position: absolute;
    right: 50%;
    top: 100%;
    z-index: 80;
    width: 200px;
    text-align: right;
    margin-right: -4in;
    color: #828282;
    padding-top: 16px;
}

div#statusarea .saved {
    padding: 2px 21px 0 0;
    background: url(../img/loading.gif) no-repeat right top;
}

div#statusarea .error {
    color: red;
}

#editor-content {
    display: flex;
    position: relative;
    top: 225px;
    max-width: 1600px;
    padding: .5in 54px 0 110px;
}

body.header-closed #toolbar {
    padding-top: 12px;
    padding-bottom: 12px;
}

body.header-closed #editor-content {
    top: 72px;
}

#flow .article-bibliography {
    background-color: lightgrey;
}

#paper-editable .citation,
.equation {
    cursor: pointer;
    background-color: lightgrey;
}

#paper-editable .citation:hover,
.equation:hover {
    background-color: grey;
}

#paper-editable {
    display: table;
    width: 100%;
}

#document-editable {
    display: table-cell;
    vertical-align: top;
}

div#layout {
    padding-top: 60px;
}


/*
 * Dialog
 */

.dialogSubmit {
    text-align: right;
    margin-top: 20px;
}


/* for forms */

input.required,
error {
    border: 2px solid red;
}


/* Overwrite color changes through font in editor. Webkit bug */

font {
    color: inherit !important;
}

/* Don't show parts marked as hidden*/

.article-part[data-hidden] {
    display: none;
}


/* For default contents of title and contents field*/

.article-part:before {
    text-transform: none;
    color: #cecece;
}


/* For Firefox problem: shows input fields without height. */

.article-part {
    min-height: 1.5em;
    line-height: initial;
    /* Cancel out 1.6em line height for metadata/title. */
}


/* overwrite dropkick layout for access rights dialogue */

.access-rights-dialog select {
    position: static;
    visibility: inherit;
    top: 0;
}


/* delete icon in access rights dialogue */

span.delete {
    cursor: pointer;
}

.article-title:focus,
.article-body:focus {
    outline: none;
}

.pagination-footnote-item {
    width: 100%;
}

.pagination-footnote-item-container {
    cursor: pointer;
}

.pagination-footnote-item-container::before {
    content: '\0000a0x';
    position: absolute;
    visibility: hidden;
    font-weight: bold;
}

.pagination-footnote-item-container:hover::before {
    visibility: visible;
}

.pagination-footnote-item-container>div {
    margin-left: 15px;
}

.article-body,
.pagination-footnote>*>* {
    font-size: 12pt;
}


/* Prevent user from writing in the footnote editor while there are no footnotes. */

#footnote-box-container div.ProseMirror:empty {
    display: none;
}

#flow {
    padding: 50px;
    position: relative;
    width: 100%;
    bottom: 50px;
}

#flow.hide {
    display: none;
}

#flow {
    background-color: white;
}

#document-editable {
    white-space: pre-wrap;
}

.ProseMirror {
    border: none !important;
}

.ProseMirror {
    padding: 0 !important;
    line-height: inherit !important;
}

.ProseMirror table {
    border-collapse: collapse;
    table-layout: fixed;
}

.ProseMirror td,
.ProseMirror th {
    vertical-align: top;
    border: 1px solid #ddd;
    padding: 3px 5px;
}

.ProseMirror th {
    background-color: #76a698;
    color: #fff;
}

#comments-filter {
    margin-left: 7px;
}

#unobtrusive_messages {
    position: fixed;
    bottom: 0;
    left: 100px;
    background-color: #f9f9f9;
    border-top: 1px solid #e0e0e0;
    border-right: 1px solid #e0e0e0;
    border-left: 1px solid #e0e0e0;
    padding: 4px;
}

#unobtrusive_messages .warn {
    color: #b73717;
}

#unobtrusive_messages:empty {
    display: none;
}


/* Show key bindings menu */

.help-key {
    float: none;
    line-height: 1.5;
    position: relative;
    bottom: 4px;
}

.help-list-wrap {
    overflow: hidden;
    margin: 0 auto;
    -webkit-transition: width .2s linear;
    -moz-transition: width .2s linear;
    -o-transition: width .2s linear;
    transition: width .2s linear;
}

.help-list {
    list-style: none;
    margin: 0;
    padding: 0 0 10px 0;
    overflow: hidden;
    float: left;
    width: 330px;
}

.help-list li {
    margin-right: 40px;
}

.help-key-unit {
    line-height: 1.8;
    margin-right: 2em;
    padding: 5px 0;
}

.help-key {
    min-width: 60px;
    float: left;
    clear: left;
    position: relative;
    bottom: 2px;
}

.help-key span {
    font-size: 15px;
    color: #555;
    display: inline-block;
    padding: 0 8px;
    text-align: center;
    background-color: #fff;
    background-repeat: repeat-x;
    background-image: linear-gradient(#f5f5f5 0%, #eee 100%);
    border: 1px solid #ccc;
    border-radius: 3px;
    -webkit-box-shadow: inset 0 1px 0 #fff, 0 1px 0 #ccc;
    box-shadow: inset 0 1px 0 #fff, 0 1px 0 #ccc;
}

.help-key-def {
    display: inline-block;
    margin-left: 1em;
}


.image-selection-table tr {
    cursor: pointer;
}

/* MathLive Editor Overwrite */

.math-field {
    background-color: white;
    margin: 9px 10px 7px 10px;
    padding-left: 5px;
    font-size: 20px;
    display: block;
    padding-top: 10px;
    padding-bottom: 10px;
    border: solid 1px #d3d3d3;
    cursor: text;
    position: relative;
}

.math-field .placeholder {
    position: absolute;
    top: 20px;
    left: 10px;
    color: #d3d3d3;
}

.math-latex {
    display: block;
    min-width: 250px;
    margin: 5px 0 5px 0;
    font-size: 18px;
    padding-left: 5px;
}

/* .math-field-header {
    font-size: 113%;
    font-weight: 400;
} */

/* .math-error {
    margin: 10px 0px;
    padding: 12px;
    color: #D8000C;
    background-color: #FFBABA;
    font-size: 2em;
    vertical-align: middle;
    display: none;
} */

.ML__popover {
    z-index: 1000;
}

/* .ML__base:empty:before, .ML__base > span:first-child:empty:before {
    content: 'Type here';
} */

div.table-edit-button-group {
    margin-bottom: 10px;
    text-align: left;
}

table.insert-table-selection {
    margin: 10px 0 10px 0;
}

table.insert-table-selection,
table.insert-table-selection td {
    border: 1px solid #ddd;
}

table.insert-table-selection td {
    min-width: 30px;
    height: 18px;
}

table.insert-table-selection td.hover {
    background-color: #e0e0e0;
}

table.insert-table-selection td.selected {
    background-color: #4f4d4f;
}

table.insert-table-selection td.selected.hover {
    background-color: #585858;
}

.ProseMirror td.selectedCell {
    background-color: #8cf;
    caret-color: transparent;
}


/* Wide table: used for submission dialog */

.fw-dialog-table-wide .entry-field input[type=text],
.fw-dialog-table-wide .entry-field textarea {
    width: 678px;
}

.fw-dialog-table-wide .entry-field textarea {
    resize: none;
}

.fw-dialog-table-wide th {
    vertical-align: top;
    padding: 0 6px 0 8px;
    width: 164px;
}


/* Links  & Anchors */

.drop-up-outer {
    position: absolute;
}

.drop-up-inner {
    position: relative;
    background-color: white;
    z-index: 1;
    font-weight: normal;
    color: black;
    left: 10px;
}

.drop-up-head {
    padding: 20px 22px;
    background-color: #605f5f;
    color: #ffffff;
    font-family: Lato;
    font-size: 13px;
    font-weight: 400;
    line-height: 18px;
    letter-spacing: 0.13px;
    border-radius: 6px 6px 0 0;
}

.drop-up-head .link-href a {
    opacity: 0.6;
    color: #ffffff;
    font-family: Lato;
    font-size: 12px;
    font-weight: 700;
    text-decoration: none;
}

.drop-up-head > * + * {
    margin-top: 14px;
}

.link.drop-up-inner {
    box-shadow: 0 0 20px rgba(0, 0, 0, 0.11);
    border-radius: 6px;
}

.user-contents ul.drop-up-options li {
    border-top: 1px solid #eeeeee;
    padding: 16px 30px;
    color: #2c2723;
    font-family: Lato;
    font-size: 13px;
    font-weight: 400;
    line-height: 1em;
}

.user-contents ul.drop-up-options {
    list-style: none;
    padding: 0 0 12px 0;
    cursor: pointer;
}

ul.drop-up-options li:hover {
    background-color: #eeeeee;
}

.drop-up-options .remove-link:after {
    font-family: "Font Awesome 5 Free";
    content: "\f2ed";
    opacity: 0.4;
    float: right;
    display: block;
}

.drop-up-inner .edit {
    font-size: 0.8em;
    text-align: right;
}

*:focus {
    outline: none;
}


/* Additions for tablets + mobile */
@media screen and (max-width: 1279px) {
    #document-top>h1 {
        padding-left: 52px;
        background-position: 14px 0;
    }

    #header-navigation {
        margin-left: 52px;
    }

    .editor-toolbar div.ui-buttonset:first-child {
        left: 3px;
    }

    .editor-toolbar {
        padding-left: 52px;
    }

    #editor-content {
        padding-left: 52px;
        padding-right: 30px;
    }
}


@media screen and (max-width: 1023px) {
    #editor-content {
        padding-right: 15px;
    }
    #flow {
        padding-left: 8px;
    }
    #document-top>h1 {
        background: initial;
        padding-left: 8px;
    }
    #header-navigation {
        margin-left: 8px;
    }
}

.ProseMirror-gapcursor {
    display: none;
    pointer-events: none;
    position: absolute;
}


/* gapcursor related */

.ProseMirror-gapcursor:after {
    content: "";
    display: block;
    position: absolute;
    top: -2px;
    width: 20px;
    border-top: 1px solid black;
    animation: ProseMirror-cursor-blink 1.1s steps(2, start) infinite;
}

@keyframes ProseMirror-cursor-blink {
    to {
        visibility: hidden;
    }
}

.ProseMirror-focused .ProseMirror-gapcursor {
    display: block;
}


/* For users who use one of the inverted high contrast modes. Likely want
as much black as possible. */

html[hc=a3] .ui-widget-overlay,
html[hc=a4] .ui-widget-overlay,
html[hc=a5] .ui-widget-overlay {
    background-color: rgba(255, 255, 255, 0.8);
}

html[hc=a3] body,
html[hc=a4] body,
html[hc=a5] body {
    background-color: white;
}

html[hc=a3] #toolbar,
html[hc=a4] #toolbar,
html[hc=a5] #toolbar {
    border-bottom: 1px solid #e0e0e0;
}

#close-document-top {
    position: fixed;
    right: 30px;
    top: 28px;
    z-index: 100;
}

#close-document-top a, #close-document-top .fw-link-text {
    width: 10px;
    height: 10px;
    opacity: 0.6;
    color: #ffffff;
    font-size: 14px;
    font-weight: 400;
    line-height: 25px;
    letter-spacing: -0.35px;
}

.article-part.article-deleted {
    border: 3px solid #d3421c;
    border-radius: 5px;
    padding: 10px 20px 10px 10px;
    margin: 5px 0;
    position: relative;
}

.remove-article-part {
    position: absolute;
    top: 5px;
    right:  5px;
    cursor: pointer;
    font-size: 16px;
}

.remove-article-part:hover {
    color: #d3421c;
}

.editor .article .table-of-contents {
    background-color: lightgrey;
    padding: 10px;
}

#navigator {
    top: 250px;
    left: 0;
    position: fixed;
    z-index: 9;
}

#navigator.opened #navigator-content {
    transform: translateX(0);
}

#navigator-content {
    position: fixed;
    top: auto;
    left: 0;
    display: block;
    background-color: rgba(0,0,0,0.8);
    min-width: 216px;
    max-width:480px;
    color: white;
    padding: 15px 30px 15px 50px;
    box-sizing: border-box;
    font-size: 13px;
    line-height: 1.2;
    transform: translateX(-100%);
    transition: transform 0.2s ease-out;
}

#navigator-list {
    max-height: 550px;
    overflow-y: scroll;
    -ms-overflow-style: none;
    overflow: -moz-scrollbars-none;
}

#navigator-filter span {
    display: block;
    padding-bottom: 10px;
}

#navigator-list.hide,
#navigator-filter.hide {
    display: block;
    height: 0;
    overflow: hidden;
}

#navigator-list::-webkit-scrollbar {
    width: 5px;
}

::-webkit-scrollbar-thumb {
    background: #181818;
    border-radius: 10px;
}

::-webkit-scrollbar-thumb:hover {
    cursor: pointer;
    background: #0f0f0f;
}

#navigator-content a {
    color: white;
}

#navigator-list > * {
    padding-bottom: 12px;
}

#navigator-list a:hover {
    text-decoration: underline;
}

#navigator-content h2 {
    padding-left: 1em;
}
#navigator-content h3 {
    padding-left: 2em;
}
#navigator-content h4 {
    padding-left: 3em;
}
#navigator-content h5 {
    padding-left: 4em;
}
#navigator-content h6 {
    padding-left: 5em;
}
#navigator-content .header {
    text-transform: uppercase;
    padding-bottom: 20px;
}
.header-container {
    position: relative;
    padding-right: 28px;
}

.active-heading {
    text-decoration: underline;
}

#navigator-button {
    position: absolute;
    left: 0;
    top: 0;
    display: block;
    width: 42px;
    height: 42px;
    text-align: center;
    line-height: 42px;
    background-color: #303030;
    cursor: pointer;
    z-index: 4;
}
.navigator-arrow-icon {
    color: white;
}
.navigator-arrow-icon i {
    transition: all 0.50s 0.25s;
}
.rotate {
    transform: rotate(180deg);
}

#navigator-filter-icon,
#navigator-filter-back {
    cursor: pointer;
    position: absolute;
    right: 0;
    top: 0;
}

#navigator-filter-icon {
    transition: transform 0.2s;
}

#navigator-filter-icon:hover {
    transform: rotate(90deg);
}

.form-checkbox {
    -webkit-appearance: none;
    -moz-appearance: none;
    appearance: none;
    display: inline-block;
    position: relative;
    background-color: white;
    color: #444;
    top: 5px;
    height: 18px;
    width: 18px;
    border: 0;
    border-radius: 3px;
    cursor: pointer;
    margin-right: 7px;
    outline: none;
}
.form-checkbox:checked::before {
    position: absolute;
    left: 3px;
    content: '\2713';
    font-weight: bold;
    font-size: 1.2em;
}
.form-checkbox:hover {
    background-color: #f7f7f7;
}
.form-checkbox:checked {
    background-color: #f1f1f1;
}
.navigator-label {
    color: white;
    cursor: pointer;
    display: inline-block;
    vertical-align: middle;
}
.hide {
    display: none;
}
body.no-scroll {
    overflow: hidden;
}
