.ui-tabs-nav {
    width: auto;
    height: 41px;
    margin-right: 49px;
}

.ui-tabs-nav > li {
    position: relative;
    float: left;
    margin-right: 4px;
}

.ui-tabs-nav .fw-button {
    color: #000;
    border-color: #e0e0e0;
    background: #f9f9f9;
}

.ui-tabs-nav .fw-button:hover,
.ui-tabs-nav .ui-tabs-active .fw-button  {
    background: #f9f9f9;
}

.ui-tabs-panel {
    height: auto;
    overflow: auto;
    min-height: 220px;
    padding: 0;
    margin-top: 24px;
}
