.table-container {
    position: relative;
    z-index: 5;
}
.table-menu-btn {
    background-color: Transparent;
    background-repeat:no-repeat;
    border: 1px;
    cursor:pointer;
    overflow: hidden;
    outline:none;
    position: absolute;
    right: -15px;
    top: 0px;
}

.figure-menu-btn {
    background-color: Transparent;
    background-repeat:no-repeat;
    border: 1px;
    cursor:pointer;
    overflow: hidden;
    outline:none;
    right: -22px;
    top: -7px;
    float: right;
    position: relative;
}

.dot-menu-icon {
    font-size: 18px;
    color:#cecece;
}

.dot-menu-icon:hover {
    color:#000;
}
