# Generated by Django 2.2.4 on 2019-08-31 14:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('document', '0018_documenttemplate_import_id'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='documenttemplate',
            name='definition_hash',
        ),
    ]
